@@ -286,7 +286,7 @@ public:
             qCWarning(cfLog, "Can't acquire config manager. error:\"%s\"", qPrintable(dbus_reply.error().message()));
             return false;
         } else {
-            qCWarning(cfLog(), "dbus path=\"%s\"", qPrintable(dbus_path.path()));
+            qCDebug(cfLog(), "dbus path=\"%s\"", qPrintable(dbus_path.path()));
             config.reset(new DSGConfigManager(DSG_CONFIG_MANAGER, dbus_path.path(),
                                                 QDBusConnection::systemBus(), owner->q_func()));
             if (!config->isValid()) {
@@ -341,9 +341,13 @@ public:
 
     virtual QVariant value(const QString &key, const QVariant &fallback) const override
     {
-        const QDBusVariant &dv = config->value(key);
-        const QVariant &v = dv.variant();
-        return v.isValid() ? decodeQDBusArgument(v) : fallback;
+        auto reply = config->value(key);
+        reply.waitForFinished();
+        if (reply.isError()) {
+            qWarning() << "value error key:" << key << ", error message:" << reply.error().message();
+            return fallback;
+        }
+        return decodeQDBusArgument(reply.value().variant());
     }
 
     virtual void setValue(const QString &key, const QVariant &value) override
