@@ -152,7 +152,7 @@ static DConfigFile::Version parseVersion(const QJsonObject &obj) {
 #define MAGIC_OVERRIDE QLatin1String("dsg.config.override")
 #define MAGIC_CACHE QLatin1String("dsg.config.cache")
 
-static const uint GlobalUID = 0xFFFF;
+static const uint InvalidUID = 0xFFFF;
 
 inline static bool checkMagic(const QJsonObject &obj, QLatin1String request) {
     return obj[QLatin1String("magic")].toString() == request;
@@ -386,14 +386,18 @@ public:
         values.remove(key);
     }
 
-    inline void update(const QString &key, const QVariantHash &value)
+    inline bool update(const QString &key, const QVariantHash &value)
     {
+        if (!value.contains("value")) {
+            return false;
+        }
         values[key] = value;
+        return true;
     }
 
-    inline void updateValue(const QString &key, const QJsonValue &value)
+    inline bool updateValue(const QString &key, const QJsonValue &value)
     {
-        overrideValue(key, "value", value);
+        return overrideValue(key, "value", value);
     }
 
     inline void updateSerial(const QString &key, const QJsonValue &value)
@@ -415,11 +419,15 @@ public:
         return contents;
     }
 private:
-    void overrideValue(const QString &key, const QString &subkey, const QJsonValue &from) {
+    bool overrideValue(const QString &key, const QString &subkey, const QJsonValue &from) {
         const QJsonValue &v = from[subkey];
 
-        if (!v.isUndefined())
-            values[key][subkey] = v.toVariant();
+        if (v.isUndefined()) {
+            return false;
+        }
+
+        values[key][subkey] = v.toVariant();
+        return true;
     }
 
     QHash<QString, QVariantHash> values;
@@ -698,14 +706,15 @@ public:
 
             // 初始化原始值
             for (; i != contents.constEnd(); ++i) {
-                values.update(i.key(), i.value().toObject().toVariantHash());
+                if (!values.update(i.key(), i.value().toObject().toVariantHash())) {
+                    qWarning() << "key:" << i.key() << "has no value";
+                    return false;
+                }
             }
         }
-
         // for override
         Q_FOREACH(auto override, overrides) {
             const QJsonDocument &doc = loadJsonFile(override);
-
             if (doc.isObject()) {
                 const QJsonObject &root = doc.object();
                 if (!checkMagic(root, MAGIC_OVERRIDE)) {
@@ -734,7 +743,10 @@ public:
                     if (values.flags(i.key()) & DConfigFile::NoOverride)
                         continue;
 
-                    values.updateValue(i.key(), i.value());
+                    if (!values.updateValue(i.key(), i.value())) {
+                        qWarning() << "key (override):" << i.key() << "has no value";
+                        return false;
+                    }
                     values.updateSerial(i.key(), i.value());
                     values.updatePermissions(i.key(), i.value());
                 }
@@ -1002,6 +1014,7 @@ public:
         values.setTime(key, QDateTime::currentDateTime().toString(Qt::ISODate));
         values.setUser(key, uid);
         values.setAppId(key, appid.isEmpty() ? configKey.appId : appid);
+        cacheChanged = true;
         return true;
     }
 
@@ -1016,7 +1029,7 @@ public:
     DConfigInfo values;
     uint userid;
     bool global;
-    char padding [3] = {};
+    bool cacheChanged = false;
 };
 
 DConfigCacheImpl::DConfigCacheImpl(const DConfigKey &configKey, const uint uid, bool global)
@@ -1068,6 +1081,9 @@ bool DConfigCacheImpl::load(const QString &localPrefix)
 
 bool DConfigCacheImpl::save(const QString &localPrefix, QJsonDocument::JsonFormat format, bool sync)
 {
+    if (!cacheChanged)
+        return true;
+
     const QString &dir = getCacheDir(localPrefix);
     if (dir.isEmpty()) {
         qCWarning(cfLog, "save Falied because home directory is not exist for the user[%d].", userid);
@@ -1225,14 +1241,14 @@ DConfigFile::DConfigFile(const QString &appId, const QString &name, const QStrin
     Q_ASSERT(!name.isEmpty());
 
     D_D(DConfigFile);
-    d->globalCache = new DConfigCacheImpl(d->configKey, GlobalUID, true);
+    d->globalCache = new DConfigCacheImpl(d->configKey, InvalidUID, true);
 }
 
 DConfigFile::DConfigFile(const DConfigFile &other)
     : DObject(*new DConfigFilePrivate(this, other.d_func()->configKey))
 {
     D_D(DConfigFile);
-    auto cache = new DConfigCacheImpl(d->configKey, GlobalUID, true);
+    auto cache = new DConfigCacheImpl(d->configKey, InvalidUID, true);
     cache->values = other.d_func()->globalCache->values;
     d->globalCache = cache;
 }
